@@ -15,9 +15,8 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
-use Regexp::Common;
 
-our $VERSION = version->new('0.0.7');
+our $VERSION = version->new('0.0.8');
 
 my $opt = Getopt::Alt->new(
     {
@@ -39,9 +38,9 @@ my $opt = Getopt::Alt->new(
 
 sub _num_sort {
     my $A = $a;
-    $A =~ s/($RE{num}{real})/sprintf "%013f", $1/egxms;
+    $A =~ s/(\d+)/sprintf "%013d", $1/egxms;
     my $B = $b;
-    $B =~ s/($RE{num}{real})/sprintf "%013f", $1/egxms;
+    $B =~ s/(\d+)/sprintf "%013d", $1/egxms;
     $A cmp $B;
 }
 
@@ -66,6 +65,7 @@ sub since_release {
     elsif (!@tags) {
         return;
     }
+    warn join ', ', @tags, "\n";
 
     my ($sha, $time) = split /\s+/, `git log -n 1 --format=format:'%H %at' $tags[-1]`;
 
@@ -78,7 +78,7 @@ sub since_release {
     }
 
     return if @logged < $opt->opt->min;
-    my $text = $opt->opt->quiet ? '' : "Commits since last release";
+    my $text = $opt->opt->quiet ? '' : "Commits since last release ($tags[-1])";
     $text .= $opt->opt->name ? " ($tags[-1]): " : ': ';
 
     return $text . ($opt->opt->verbose ? "\n" . join '', @logged : scalar @logged);
@@ -94,7 +94,7 @@ Group::Git::Cmd::SinceRelease - Gets the number of commits each repository is ah
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.7
+This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.8
 
 =head1 SYNOPSIS
 
